@@ -37,7 +37,6 @@ from .providers import get_provider
 from .utils.files import (
     create_file_content,
     download_file,
-    encode_file_base64,
     get_file_info,
     get_file_type,
     is_file_message,
@@ -167,8 +166,8 @@ class Agent:
         self._init_provider()
         
         # Setup messaging and file directory
-        self.file_cache_dir = "/tmp/agent_files"
-        os.makedirs(self.file_cache_dir, exist_ok=True)
+        self.file_cache_dir = Path("/tmp/agent_files")
+        self.file_cache_dir.mkdir(exist_ok=True, parents=True)
         
         # Initialize messaging client
         if messaging_enabled:
@@ -461,11 +460,8 @@ You should:
                 # Use the existing client but ensure it has the right conversation
                 self.messaging_client.conversation_id = message.conversation_id
             
-            # Process based on message type
-            if is_file_message(message.message_type, message.metadata):
-                response_content = await self.process_file_message(message)
-            else:
-                response_content = await self.process_message(message)
+            # Process message - history formatting handles file messages
+            response_content = await self.process_message(message)
             
             # Create response
             response = Response(
@@ -493,15 +489,13 @@ You should:
     
     async def process_message(
         self, 
-        message: Message, 
-        content: Optional[Union[str, List[Dict[str, Any]]]] = None
+        message: Message
     ) -> str:
         """
         Process message using configured LLM provider.
         
         Args:
             message: The message to process
-            content: Optional custom content (can be string or content array for multimodal)
             
         Returns:
             Response content
@@ -554,30 +548,60 @@ You should:
             if history:
                 messages.extend(history)
                 logger.debug(f"Added {len(history)} historical messages to conversation")
-            
-            # Add current message
-            if content is not None:
-                messages.append({
-                    "role": "user",
-                    "content": content
-                })
-                logger.debug("Added current message with custom content")
-                if isinstance(content, list):
-                    logger.debug(f"Current message is multimodal with {len(content)} parts")
+                # History already includes the current message from backend
+                # No need to add it again
             else:
+                # No history means this is the first message
+                # Need to add it manually since backend might not have stored it yet
+                logger.debug("No history found, adding current message")
                 messages.append({
                     "role": "user",
                     "content": message.content
                 })
-                logger.debug(f"Added current message with text content: {message.content[:100]}...")
             
             # Get all tools from the registry
             all_tools = self.tool_registry.get_all_tools()
             
+            # Check if we need to switch to a different model based on content
+            model_to_use = self.config.model
+            if self.config.provider == "openai":
+                # Only check the most recent user message
+                has_audio = False
+                has_image = False
+                
+                # Find the last user message
+                for msg in reversed(messages):
+                    if msg.get('role') == 'user':
+                        content = msg.get('content', '')
+                        
+                        # Check for audio
+                        if isinstance(content, str) and '[Audio file' in content and '(URL:' in content:
+                            has_audio = True
+                        
+                        # Check for images in multimodal content
+                        elif isinstance(content, list):
+                            for part in content:
+                                if part.get('type') == 'image_url':
+                                    has_image = True
+                                    break
+                        
+                        # Only check the most recent user message
+                        break
+                
+                # Switch to audio model if needed
+                if has_audio and hasattr(self.provider, 'is_audio_model') and not self.provider.is_audio_model(model_to_use):
+                    logger.info(f"Switching from {model_to_use} to gpt-4o-audio-preview for audio processing")
+                    model_to_use = "gpt-4o-audio-preview"
+                
+                # Switch to vision model if needed
+                elif has_image and hasattr(self.provider, 'is_vision_model') and not self.provider.is_vision_model(model_to_use):
+                    logger.info(f"Switching from {model_to_use} to gpt-4o for image processing")
+                    model_to_use = "gpt-4o"
+            
             # Process with provider
             response = await self.provider.process(
                 messages=messages,
-                model=self.config.model,
+                model=model_to_use,
                 temperature=self.config.temperature,
                 max_tokens=self.config.max_tokens,
                 tools=all_tools if all_tools else None,
@@ -645,81 +669,6 @@ You should:
             logger.error(f"Error processing message: {e}")
             return f"I encountered an error while processing your request: {str(e)}"
     
-    async def process_file_message(self, message: Message) -> str:
-        """
-        Process messages containing files.
-        
-        Args:
-            message: Message with file metadata
-            
-        Returns:
-            Response content
-        """
-        try:
-            file_info = get_file_info(message.metadata)
-            if not file_info:
-                return "I received a file but couldn't extract its information."
-            
-            # Download the file
-            file_path = await download_file(
-                file_info['url'],
-                file_info['name'],
-                self.file_cache_dir
-            )
-            
-            if not file_path:
-                return f"I received your file '{file_info['name']}' but had trouble downloading it."
-            
-            # Get file type
-            file_type = get_file_type(file_info['mime_type'])
-            user_text = message.content or "What's in this file?"
-            
-            # Handle different file types
-            if file_type == 'image':
-                # For images, create multimodal content
-                base64_data, mime_type = encode_file_base64(file_path)
-                content = [
-                    {"type": "text", "text": user_text},
-                    {
-                        "type": "image_url",
-                        "image_url": {
-                            "url": f"data:{mime_type};base64,{base64_data}"
-                        }
-                    }
-                ]
-                
-                # Ensure we're using a vision-capable model
-                if self.config.provider == "openai" and hasattr(self.provider, 'is_vision_model'):
-                    if not self.provider.is_vision_model(self.config.model):
-                        # Switch to vision model
-                        original_model = self.config.model
-                        self.config.model = "gpt-4o-mini"
-                        response = await self.process_message(message, content)
-                        self.config.model = original_model  # Restore
-                        return response
-                
-            elif file_type == 'audio':
-                # Handle audio transcription
-                if self.config.provider == "openai" and hasattr(self.provider, 'transcribe'):
-                    try:
-                        transcription = await self.provider.transcribe(str(file_path))
-                        content = f"{user_text}\n\nTranscription of audio file '{file_info['name']}':\n\n{transcription}"
-                    except Exception as e:
-                        logger.error(f"Error transcribing audio: {e}")
-                        content = f"{user_text}\n\n[Audio file '{file_info['name']}' - transcription failed]"
-                else:
-                    content = f"{user_text}\n\n[Audio file '{file_info['name']}' - transcription not available for {self.config.provider}]"
-            
-            else:
-                # For text files, PDFs, and code, create file content
-                content = create_file_content(file_path, file_info, user_text)
-            
-            # Process with the prepared content
-            return await self.process_message(message, content)
-            
-        except Exception as e:
-            logger.error(f"Error processing file: {e}")
-            return "I received your file but encountered an error processing it."
     
     async def health_check(self) -> Dict[str, Any]:
         """Get agent health status."""
