@@ -20,12 +20,13 @@ _PROVIDERS = {
 }
 
 
-def get_provider(name: str) -> Provider:
+def get_provider(name: str, **kwargs) -> Provider:
     """
     Get a provider instance by name.
     
     Args:
         name: Provider name (e.g., "openai", "anthropic")
+        **kwargs: Additional arguments for provider initialization
         
     Returns:
         Provider instance
@@ -40,4 +41,4 @@ def get_provider(name: str) -> Provider:
         )
     
     provider_class = _PROVIDERS[name]
-    return provider_class()
\ No newline at end of file
+    return provider_class(**kwargs)
\ No newline at end of file
