@@ -149,6 +149,16 @@ class OpenAIProvider(Provider):
                 **kwargs  # Allow additional parameters
             }
             
+            # Add modalities for audio models
+            if self.is_audio_model(model):
+                request_params["modalities"] = ["text", "audio"]
+                # Add audio configuration if not already present
+                if "audio" not in request_params:
+                    request_params["audio"] = {
+                        "voice": "alloy",
+                        "format": "wav"
+                    }
+            
             if tools:
                 request_params["tools"] = tools
             
@@ -262,12 +272,12 @@ class OpenAIProvider(Provider):
     
     def is_vision_model(self, model: str) -> bool:
         """Check if a model supports vision capabilities."""
-        vision_models = ['gpt-4o', 'gpt-4o-mini', 'gpt-4-vision-preview', 'gpt-4-turbo', 'o1']
+        vision_models = ['gpt-4o', 'gpt-4-vision-preview', 'gpt-4-turbo', 'gpt-4.1', 'o1']
         return any(model.startswith(vm) for vm in vision_models)
     
     def is_audio_model(self, model: str) -> bool:
-        """Check if a model supports audio capabilities."""
-        audio_models = ['gpt-4o-audio-preview']
+        """Check if a model supports native audio input/output capabilities."""
+        audio_models = ['gpt-4o-audio-preview', 'gpt-4o-mini-audio-preview']
         return any(model.startswith(am) for am in audio_models)
     
     async def generate_speech(
