@@ -12,8 +12,6 @@ from .files import (
 )
 from .tools import (
     init_tools,
-    execute_tools,
-    format_tool_results,
     get_tool_provider,
     register_tool_provider,
     ToolProvider,
@@ -25,6 +23,15 @@ from .audio import (
     ensure_supported_format,
     check_ffmpeg_available,
 )
+from .scheduling import (
+    validate_cron_expression,
+    parse_natural_schedule,
+    calculate_next_run,
+    format_schedule_description,
+    merge_schedule_configs,
+    create_schedule_from_yaml,
+    ScheduleStatePersistence,
+)
 
 __all__ = [
     # File utilities
@@ -36,8 +43,6 @@ __all__ = [
     "create_file_content",
     # Tool utilities
     "init_tools",
-    "execute_tools",
-    "format_tool_results",
     "get_tool_provider",
     "register_tool_provider",
     "ToolProvider",
@@ -47,4 +52,12 @@ __all__ = [
     "convert_audio_to_wav",
     "ensure_supported_format",
     "check_ffmpeg_available",
+    # Scheduling utilities
+    "validate_cron_expression",
+    "parse_natural_schedule",
+    "calculate_next_run",
+    "format_schedule_description",
+    "merge_schedule_configs",
+    "create_schedule_from_yaml",
+    "ScheduleStatePersistence",
 ]
\ No newline at end of file
